@@ -4,7 +4,7 @@
 import logging
 from typing import Union, Dict, List
 from python_byzatic_commons.flattener.dl_flattener import DLFlattener
-from flattener.interfaces import JsonFlattenerInterface
+from python_byzatic_commons.flattener.interfaces import JsonFlattenerInterface
 
 
 class JsonFlattener(JsonFlattenerInterface):
